changeset 61983:f58aeabf21e7

(Vexecuting_kbd_macro): Renamed from Vexecuting_macro. All uses changed. (syms_of_macros): Define only executing-kbd-macro, not executing-macro.
author Richard M. Stallman <rms@gnu.org>
date Sun, 01 May 2005 18:48:26 +0000
parents 237065917c73
children 2ce055c7db65
files src/macros.c
diffstat 1 files changed, 11 insertions(+), 13 deletions(-) [+]
line wrap: on
line diff
--- a/src/macros.c	Sun May 01 18:47:16 2005 +0000
+++ b/src/macros.c	Sun May 01 18:48:26 2005 +0000
@@ -31,7 +31,7 @@
 
 /* Kbd macro currently being executed (a string or vector).  */
 
-Lisp_Object Vexecuting_macro;
+Lisp_Object Vexecuting_kbd_macro;
 
 /* Index of next character to fetch from that macro.  */
 
@@ -285,7 +285,7 @@
   return Qnil;
 }
 
 /* Restore Vexecuting_macro and executing_macro_index - called when
    the unwind-protect in Fexecute_kbd_macro gets invoked.  */
 
 static Lisp_Object
@@ -293,7 +293,7 @@
      Lisp_Object info;
 {
   Lisp_Object tem;
-  Vexecuting_macro = XCAR (info);
+  Vexecuting_kbd_macro = XCAR (info);
   tem = XCDR (info);
   executing_macro_index = XINT (XCAR (tem));
   real_this_command = XCDR (tem);
@@ -330,7 +330,7 @@
   if (!STRINGP (final) && !VECTORP (final))
     error ("Keyboard macros must be strings or vectors");
 
-  tem = Fcons (Vexecuting_macro,
+  tem = Fcons (Vexecuting_kbd_macro,
 	       Fcons (make_number (executing_macro_index),
 		      real_this_command));
   record_unwind_protect (pop_kbd_macro, tem);
@@ -338,7 +338,7 @@
   GCPRO2 (final, loopfunc);
   do
     {
-      Vexecuting_macro = final;
+      Vexecuting_kbd_macro = final;
       executing_macro = final;
       executing_macro_index = 0;
 
@@ -359,11 +359,11 @@
       QUIT;
     }
   while (--repeat
-	 && (STRINGP (Vexecuting_macro) || VECTORP (Vexecuting_macro)));
+	 && (STRINGP (Vexecuting_kbd_macro) || VECTORP (Vexecuting_kbd_macro)));
 
   executing_macro = Qnil;
 
-  real_this_command = Vexecuting_macro;
+  real_this_command = Vexecuting_kbd_macro;
 
   UNGCPRO;
   return unbind_to (pdlcount, Qnil);
@@ -372,7 +372,7 @@
 void
 init_macros ()
 {
-  Vexecuting_macro = Qnil;
+  Vexecuting_kbd_macro = Qnil;
   executing_macro = Qnil;
 }
 
@@ -396,15 +396,13 @@
 The value is the symbol `append' while appending to the definition of
 an existing macro.  */);
 
-  DEFVAR_LISP ("executing-macro", &Vexecuting_macro,
-	       doc: /* Currently executing keyboard macro (string or vector); nil if none executing.  */);
+  DEFVAR_LISP ("executing-kbd-macro", &Vexecuting_kbd_macro,
+	       doc: /* Currently executing keyboard macro (string or vector).
+This is nil when not executing a keyboard macro.  */);
 
   DEFVAR_INT ("executing-macro-index", &executing_macro_index,
 	      doc: /* Index in currently executing keyboard macro; undefined if none executing.  */);
 
-  DEFVAR_LISP_NOPRO ("executing-kbd-macro", &Vexecuting_macro,
-		     doc: /* Currently executing keyboard macro (string or vector); nil if none executing.  */);
-
   DEFVAR_KBOARD ("last-kbd-macro", Vlast_kbd_macro,
 		 doc: /* Last kbd macro defined, as a string or vector; nil if none defined.  */);
 }
@@ -285,7 +285,7 @@
 }
 
-/* Restore Vexecuting_macro and executing_macro_index - called when
+/* Restore Vexecuting_kbd_macro and executing_macro_index - called when
    the unwind-protect in Fexecute_kbd_macro gets invoked.  */
 